@@ -94,9 +94,15 @@ GtkWidget* create_aboutdialog (void) {
 	gtk_about_dialog_set_authors (GTK_ABOUT_DIALOG (aboutdialog), authors);
 	gtk_about_dialog_set_documenters (GTK_ABOUT_DIALOG (aboutdialog), documenters);
 	gtk_about_dialog_set_translator_credits (GTK_ABOUT_DIALOG (aboutdialog), translators);
-	aboutdialog_logo_pixbuf = create_pixbuf ("deb-gview.xpm");
-	gtk_about_dialog_set_logo (GTK_ABOUT_DIALOG (aboutdialog), aboutdialog_logo_pixbuf);
-	gtk_window_set_icon (GTK_WINDOW (aboutdialog), aboutdialog_logo_pixbuf);
+	aboutdialog_logo_pixbuf = create_pixbuf ("deb-gview.png");
+	if (aboutdialog_logo_pixbuf) {
+		gtk_about_dialog_set_logo (GTK_ABOUT_DIALOG (aboutdialog), aboutdialog_logo_pixbuf);
+		gtk_window_set_icon (GTK_WINDOW (aboutdialog), aboutdialog_logo_pixbuf);
+	}
+	else {
+		g_warning("Failed to set png image as icon");
+	}
+	
 
 	/* Store pointers to all widgets, for use by lookup_widget(). */
 	GLADE_HOOKUP_OBJECT_NO_REF (aboutdialog, aboutdialog, "aboutdialog");
@@ -130,11 +136,14 @@ GtkWidget* create_deb_gview_window (void) {
 	deb_gview_window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 	gtk_widget_set_size_request (deb_gview_window, 600, 400);
 	gtk_window_set_title (GTK_WINDOW (deb_gview_window), _("Debian package file viewer"));
-	deb_gview_window_icon_pixbuf = create_pixbuf ("deb-gview.xpm");
+	deb_gview_window_icon_pixbuf = create_pixbuf ("deb-gview.png");
 	if (deb_gview_window_icon_pixbuf) {
 		gtk_window_set_icon (GTK_WINDOW (deb_gview_window), deb_gview_window_icon_pixbuf);
 		g_object_unref (deb_gview_window_icon_pixbuf);
 	}
+	else {
+		g_warning("Failed to set png image as icon");
+	}
 
 	vbox1 = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 	gtk_widget_show (vbox1);
