@@ -63,7 +63,7 @@ GtkWidget* lookup_widget (GtkWidget *widget, const gchar *widget_name) {
 
 /* This is an internally used function to find pixmap files. */
 static gchar* find_pixmap_file (const gchar *filename) {
-	gchar *pathname = g_strdup_printf ("/usr/share/pixmaps/%s", filename);
+	gchar *pathname = g_strdup_printf ("/usr/share/icons/hicolor/64x64/apps/%s", filename);
 	if (g_file_test (pathname, G_FILE_TEST_EXISTS)) {
 		return pathname;
 	}
